
From: Kumar Gala <galak@freescale.com>

Made the number of TLB CAM entries private and converted the board
consumers to use num_tlbcam_entries which is setup at boot time from
configuration registers.  This way the only consumers of the #define
NUM_TLBCAMS are the arrays used to manage the TLB.

Signed-off-by: Kumar Gala <kumar.gala@freescale.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/ppc/mm/fsl_booke_mmu.c                  |    2 ++
 arch/ppc/mm/mmu_decl.h                       |    2 ++
 arch/ppc/mm/pgtable.c                        |    1 -
 arch/ppc/platforms/85xx/mpc8540_ads.c        |    4 ++--
 arch/ppc/platforms/85xx/mpc85xx_cds_common.c |    4 ++--
 arch/ppc/platforms/85xx/sbc8560.c            |    4 ++--
 include/asm-ppc/pgtable.h                    |    2 --
 7 files changed, 10 insertions(+), 9 deletions(-)

diff -puN arch/ppc/mm/fsl_booke_mmu.c~ppc32-clean-up-num_tlbcams-usage-for-freescale-book-e-ppcs arch/ppc/mm/fsl_booke_mmu.c
--- 25/arch/ppc/mm/fsl_booke_mmu.c~ppc32-clean-up-num_tlbcams-usage-for-freescale-book-e-ppcs	2005-06-08 23:04:31.000000000 -0700
+++ 25-akpm/arch/ppc/mm/fsl_booke_mmu.c	2005-06-08 23:04:31.000000000 -0700
@@ -64,6 +64,8 @@ extern unsigned long total_lowmem;
 extern unsigned long __max_low_memory;
 #define MAX_LOW_MEM	CONFIG_LOWMEM_SIZE
 
+#define NUM_TLBCAMS	(16)
+
 struct tlbcam {
    	u32	MAS0;
 	u32	MAS1;
diff -puN arch/ppc/mm/mmu_decl.h~ppc32-clean-up-num_tlbcams-usage-for-freescale-book-e-ppcs arch/ppc/mm/mmu_decl.h
--- 25/arch/ppc/mm/mmu_decl.h~ppc32-clean-up-num_tlbcams-usage-for-freescale-book-e-ppcs	2005-06-08 23:04:31.000000000 -0700
+++ 25-akpm/arch/ppc/mm/mmu_decl.h	2005-06-08 23:04:31.000000000 -0700
@@ -43,6 +43,8 @@ extern int mem_init_done;
 extern PTE *Hash, *Hash_end;
 extern unsigned long Hash_size, Hash_mask;
 
+extern unsigned int num_tlbcam_entries;
+
 /* ...and now those things that may be slightly different between processor
  * architectures.  -- Dan
  */
diff -puN arch/ppc/mm/pgtable.c~ppc32-clean-up-num_tlbcams-usage-for-freescale-book-e-ppcs arch/ppc/mm/pgtable.c
--- 25/arch/ppc/mm/pgtable.c~ppc32-clean-up-num_tlbcams-usage-for-freescale-book-e-ppcs	2005-06-08 23:04:31.000000000 -0700
+++ 25-akpm/arch/ppc/mm/pgtable.c	2005-06-08 23:04:31.000000000 -0700
@@ -66,7 +66,6 @@ void setbat(int index, unsigned long vir
 
 #ifdef HAVE_TLBCAM
 extern unsigned int tlbcam_index;
-extern unsigned int num_tlbcam_entries;
 extern unsigned long v_mapped_by_tlbcam(unsigned long va);
 extern unsigned long p_mapped_by_tlbcam(unsigned long pa);
 #else /* !HAVE_TLBCAM */
diff -puN arch/ppc/platforms/85xx/mpc8540_ads.c~ppc32-clean-up-num_tlbcams-usage-for-freescale-book-e-ppcs arch/ppc/platforms/85xx/mpc8540_ads.c
--- 25/arch/ppc/platforms/85xx/mpc8540_ads.c~ppc32-clean-up-num_tlbcams-usage-for-freescale-book-e-ppcs	2005-06-08 23:04:31.000000000 -0700
+++ 25-akpm/arch/ppc/platforms/85xx/mpc8540_ads.c	2005-06-08 23:04:31.000000000 -0700
@@ -88,7 +88,7 @@ mpc8540ads_setup_arch(void)
 #ifdef CONFIG_SERIAL_TEXT_DEBUG
 	/* Invalidate the entry we stole earlier the serial ports
 	 * should be properly mapped */
-	invalidate_tlbcam_entry(NUM_TLBCAMS - 1);
+	invalidate_tlbcam_entry(num_tlbcam_entries - 1);
 #endif
 
 	/* setup the board related information for the enet controllers */
@@ -150,7 +150,7 @@ platform_init(unsigned long r3, unsigned
 		struct uart_port p;
 
 		/* Use the last TLB entry to map CCSRBAR to allow access to DUART regs */
-		settlbcam(NUM_TLBCAMS - 1, binfo->bi_immr_base,
+		settlbcam(num_tlbcam_entries - 1, binfo->bi_immr_base,
 			  binfo->bi_immr_base, MPC85xx_CCSRBAR_SIZE, _PAGE_IO, 0);
 
 		memset(&p, 0, sizeof (p));
diff -puN arch/ppc/platforms/85xx/mpc85xx_cds_common.c~ppc32-clean-up-num_tlbcams-usage-for-freescale-book-e-ppcs arch/ppc/platforms/85xx/mpc85xx_cds_common.c
--- 25/arch/ppc/platforms/85xx/mpc85xx_cds_common.c~ppc32-clean-up-num_tlbcams-usage-for-freescale-book-e-ppcs	2005-06-08 23:04:31.000000000 -0700
+++ 25-akpm/arch/ppc/platforms/85xx/mpc85xx_cds_common.c	2005-06-08 23:04:31.000000000 -0700
@@ -446,7 +446,7 @@ mpc85xx_cds_setup_arch(void)
 #ifdef CONFIG_SERIAL_TEXT_DEBUG
 	/* Invalidate the entry we stole earlier the serial ports
 	 * should be properly mapped */
-	invalidate_tlbcam_entry(NUM_TLBCAMS - 1);
+	invalidate_tlbcam_entry(num_tlbcam_entries - 1);
 #endif
 
 	/* setup the board related information for the enet controllers */
@@ -528,7 +528,7 @@ platform_init(unsigned long r3, unsigned
 		struct uart_port p;
 
 		/* Use the last TLB entry to map CCSRBAR to allow access to DUART regs */
-		settlbcam(NUM_TLBCAMS - 1, binfo->bi_immr_base,
+		settlbcam(num_tlbcam_entries - 1, binfo->bi_immr_base,
 				binfo->bi_immr_base, MPC85xx_CCSRBAR_SIZE, _PAGE_IO, 0);
 
 		memset(&p, 0, sizeof (p));
diff -puN arch/ppc/platforms/85xx/sbc8560.c~ppc32-clean-up-num_tlbcams-usage-for-freescale-book-e-ppcs arch/ppc/platforms/85xx/sbc8560.c
--- 25/arch/ppc/platforms/85xx/sbc8560.c~ppc32-clean-up-num_tlbcams-usage-for-freescale-book-e-ppcs	2005-06-08 23:04:31.000000000 -0700
+++ 25-akpm/arch/ppc/platforms/85xx/sbc8560.c	2005-06-08 23:04:31.000000000 -0700
@@ -125,7 +125,7 @@ sbc8560_setup_arch(void)
 #ifdef CONFIG_SERIAL_TEXT_DEBUG
 	/* Invalidate the entry we stole earlier the serial ports
 	 * should be properly mapped */ 
-	invalidate_tlbcam_entry(NUM_TLBCAMS - 1);
+	invalidate_tlbcam_entry(num_tlbcam_entries - 1);
 #endif
 
 	/* setup the board related information for the enet controllers */
@@ -176,7 +176,7 @@ platform_init(unsigned long r3, unsigned
 
 #ifdef CONFIG_SERIAL_TEXT_DEBUG
 	/* Use the last TLB entry to map CCSRBAR to allow access to DUART regs */
-	settlbcam(NUM_TLBCAMS - 1, UARTA_ADDR,
+	settlbcam(num_tlbcam_entries - 1, UARTA_ADDR,
 		  UARTA_ADDR, 0x1000, _PAGE_IO, 0);
 #endif
 
diff -puN include/asm-ppc/pgtable.h~ppc32-clean-up-num_tlbcams-usage-for-freescale-book-e-ppcs include/asm-ppc/pgtable.h
--- 25/include/asm-ppc/pgtable.h~ppc32-clean-up-num_tlbcams-usage-for-freescale-book-e-ppcs	2005-06-08 23:04:31.000000000 -0700
+++ 25-akpm/include/asm-ppc/pgtable.h	2005-06-08 23:04:31.000000000 -0700
@@ -267,8 +267,6 @@ extern unsigned long ioremap_bot, iorema
 #define _PMD_PRESENT_MASK (PAGE_MASK)
 #define _PMD_BAD	(~PAGE_MASK)
 
-#define NUM_TLBCAMS	(16)
-
 #elif defined(CONFIG_8xx)
 /* Definitions for 8xx embedded chips. */
 #define _PAGE_PRESENT	0x0001	/* Page is valid */
_
